@@ -546,7 +546,7 @@ static int pool_write_flush(POOL_CONNECTION *cp, void *buf, int len)
 			sts = write(cp->fd, buf+offset, wlen);
 		}
 
-		if (sts > 0)
+		if (sts >= 0)
 		{
 			wlen -= sts;
 
@@ -633,7 +633,7 @@ int pool_flush_it(POOL_CONNECTION *cp)
 		  sts = write(cp->fd, cp->wbuf + offset, wlen);
 		}
 
-		if (sts > 0)
+		if (sts >= 0)
 		{
 			wlen -= sts;
 
